<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>AIAssistantWidget</name>
    <message>
        <source>Explain</source>
        <translation>Explica</translation>
    </message>
    <message>
        <source>Translate</source>
        <translation>Traduzir</translation>
    </message>
    <message>
        <source>Ask AI</source>
        <translation>Perguntar AI</translation>
    </message>
    <message>
        <source>Summary</source>
        <translation>Resumo</translation>
    </message>
</context>
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Para finalizar a gravação
clique no ícone da bandeja ou use o atalho</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Não gire a tela durante a gravação</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Capturar</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Gravando</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Fechar (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>Copiar para a área de transferência (Enter)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Captura de Tela</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Falha ao salvar. Salve-o no diretório pessoal.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visualizar</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Captura concluída</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>select-area</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Salvo em %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorar</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Área de Transferência</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Salvando o arquivo de gravação da tela, aguarde...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>O efeito janela será desativado durante o processo; e a gravação deverá ser interrompida</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Capturar</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Tela de rolagem</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>Fixar capturas de tela</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>Gravador de Tela Deepin</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Abrir pasta</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>Captura concluída e copiada para a área de transferência</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Desfazer</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
</context>
<context>
    <name>PinSaveMenuManager</name>
    <message>
        <source>Each inquiry</source>
        <translation>Cada consulta</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>Localização especificada</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>Definir caminho para salvar</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Alterar caminho ao salvar</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Área de Trabalho</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Imagens</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>Fixar capturas de tela</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Captura de tela</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Gravar</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Captura de tela</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Gravando</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Visualizar</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Gravação concluída</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Salvo em %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Gravar</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Abrir pasta</translation>
    </message>
</context>
<context>
    <name>SaveMenuManager</name>
    <message>
        <source>Each inquiry</source>
        <translation>Cada consulta</translation>
    </message>
    <message>
        <source>Specified location</source>
        <translation>Localização especificada</translation>
    </message>
    <message>
        <source>Select a location when saving</source>
        <translation>Selecionar uma localização ao salvar</translation>
    </message>
    <message>
        <source>Update the location when saving</source>
        <translation>Atualizar a localização ao salvar</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Área de Trabalho</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Imagens</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>A captura iniciará em %1s</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Obter ajuda.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>Falha ao fazer uma captura de tela completa.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>Atingiu a parte inferior da área de rolagem</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>Atingiu o comprimento máximo</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>ajustar a área de captura</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Role a roda do mouse ou clique para fazer uma captura de tela completa</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Diminuir a velocidade de rolagem</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Área inválida, clique para </translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Insira o texto aqui</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Capturar</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Sair/Salvar</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Ajuste de Tamanho</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Início rápido</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Capturar janela</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Atrasar captura</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Capturar a tela inteira</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Retângulo</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linha</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Lápis</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Desfazer</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Aumentar altura</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Aumentar altura para baixo</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Aumentar largura à esquerda</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Aumentar largura à direita</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Reduzir altura</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Reduzir altura para baixo</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Reduzir largura à esquerda</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Reduzir altura à direita</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Exibir atalhos</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Som</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Pressionamento de tecla</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Iniciar gravação</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Iniciar / Gravação</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Mouse</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Ferramentas</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Extrair texto</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Tela de rolagem</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Fixar capturas de tela</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>Iniciar OCR</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>Iniciar tela de rolagem</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Seta</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>Capturar</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>Gravar</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>Retângulo
Mantenha pressionada a tecla Shift para desenhar um quadrado</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>Elipse
Mantenha pressionada a tecla Shift para desenhar um círculo</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>Pincel
Mantenha pressionada a tecla Shift para desenhar uma linha reta</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>Ajustar a intensidade do desfoque (Role para ajustá-la)</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>Ajustar o tamanho do pincel (Role para ajustá-lo)</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>Ajustar o tamanho do texto (Role para ajustá-lo)</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>Exibir pressionamento de tecla (K)</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>Ocultar tecla (K)</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>Exibir tecla (K)</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>Ligar câmera (C)</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>Desligue câmera (C)</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Capturar</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>Configurações (F3)</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS</source>
        <translation>FPS</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Som</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Microfone</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>Áudio do sistema</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Exibir cursor</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>Exibir clique</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Salvar em</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Área de Trabalho</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>Linha (L)
Mantenha pressionada a tecla Shift para desenhar uma linha vertical ou horizontal</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>Seta (X)
Mantenha pressionada a tecla Shift para desenhar uma seta vertical ou horizontal</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>Lápis (P)</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>Desfocar (B)</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>Texto (T)</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>Tela de rolagem (Alt+I)</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>Extrair texto (Alt+O)</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>Fixar capturas de tela (Alt+P)</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>Desfazer (Ctrl+Z)</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Gravar</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Alterar caminho ao salvar</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>Efeitos de borda</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>Sombra</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Borda</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Extrair texto</translation>
    </message>
    <message>
        <source>Geometric Tools (R)
Hold down Shift to draw squares or circles.</source>
        <translation>Ferramentas geométricas (R)
Mantenha pressionada a tecla Shift para desenhar quadrados ou círculos.</translation>
    </message>
    <message>
        <source>Save to local</source>
        <translation>Salvar localmente</translation>
    </message>
    <message>
        <source>Save to %1</source>
        <translation>Salvar em %1</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>Localização especificada</translation>
    </message>
    <message>
        <source>Update the location when saving</source>
        <translation>Atualizar a localização ao salvar</translation>
    </message>
    <message>
        <source>Select a location when saving</source>
        <translation>Selecionar uma localização ao salvar</translation>
    </message>
    <message>
        <source>AI Screenshot (A)</source>
        <translation>Captura de tela AI (A)</translation>
    </message>
    <message>
        <source>Save to Desktop</source>
        <translation>Salvar no Ambiente de trabalho</translation>
    </message>
    <message>
        <source>Save to Pictures</source>
        <translation>Salvar em imagens</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Fechar (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>Copiar para a área de transferência (Enter)</translation>
    </message>
    <message>
        <source>OK (Enter)</source>
        <translation>OK (Enter)</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> Ajuste a área de gravação em %1*%2, para obter um melhor efeito de vídeo</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>No momento, a gravação em tela não é suportada</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
</context>
</TS>
